@@ -46,9 +46,14 @@
  *
  * An object representing a contact on a #TpConnection.
  *
- * Contact objects are instantiated using
- * tp_connection_get_contacts_by_handle() or
- * tp_connection_get_contacts_by_id().
+ * Contact objects support tracking a number of attributes of contacts, as
+ * described by the #TpContactFeature flags. Features can be specified when
+ * instantiating contact objects (with tp_connection_get_contacts_by_id() or
+ * tp_connection_get_contacts_by_handle()), or added to an existing contact
+ * object with tp_connection_upgrade_contacts(). For example, a client wishing
+ * to keep track of a contact's alias would set #TP_CONTACT_FEATURE_ALIAS, and
+ * then listen for the "notify::alias" signal, emitted whenever the
+ * #TpContact:alias property changes.
  *
  * Note that releasing a #TpContact object might release handle references
  * held by calling tp_cli_connection_call_request_handles(),
@@ -1768,8 +1773,7 @@ contacts_get_attributes (ContactsContext *context)
 {
   GArray *contact_attribute_interfaces =
       context->connection->priv->contact_attribute_interfaces;
-  GPtrArray *array = g_ptr_array_sized_new (
-      contact_attribute_interfaces->len);
+  GPtrArray *array;
   const gchar **supported_interfaces;
   guint i;
 
@@ -1785,6 +1789,8 @@ contacts_get_attributes (ContactsContext *context)
         TP_IFACE_QUARK_CONNECTION_INTERFACE_CONTACTS));
   g_assert (contact_attribute_interfaces != NULL);
 
+  array = g_ptr_array_sized_new (contact_attribute_interfaces->len);
+
   for (i = 0; i < contact_attribute_interfaces->len; i++)
     {
       GQuark q = g_array_index (contact_attribute_interfaces, GQuark, i);
