@@ -975,12 +975,29 @@ _tp_dbus_daemon_get_name_owner (TpDBusDaemon *self,
                                 gchar **unique_name,
                                 GError **error)
 {
-  DBusGConnection *gconn = tp_proxy_get_dbus_connection (self);
-  DBusConnection *dbc = dbus_g_connection_get_connection (gconn);
+  DBusGConnection *gconn;
+  DBusConnection *dbc;
   DBusMessage *message;
   DBusMessage *reply;
   DBusError dbus_error;
   const char *name_in_reply;
+  const GError *invalidated;
+
+  g_return_val_if_fail (TP_IS_DBUS_DAEMON (self), FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+  invalidated = tp_proxy_get_invalidated (self);
+
+  if (invalidated != NULL)
+    {
+      if (error != NULL)
+        *error = g_error_copy (invalidated);
+
+      return FALSE;
+    }
+
+  gconn = tp_proxy_get_dbus_connection (self);
+  dbc = dbus_g_connection_get_connection (gconn);
 
   message = dbus_message_new_method_call (DBUS_SERVICE_DBUS, DBUS_PATH_DBUS,
       DBUS_INTERFACE_DBUS, "GetNameOwner");
@@ -1034,7 +1051,7 @@ _tp_dbus_daemon_get_name_owner (TpDBusDaemon *self,
 }
 
 /**
- * _tp_dbus_daemon_request_name:
+ * tp_dbus_daemon_request_name:
  * @self: a TpDBusDaemon
  * @well_known_name: a well-known name to acquire
  * @idempotent: whether to consider it to be a success if this process
@@ -1042,25 +1059,44 @@ _tp_dbus_daemon_get_name_owner (TpDBusDaemon *self,
  * @error: used to raise an error if %FALSE is returned
  *
  * Claim the given well-known name without queueing, allowing replacement
- * or replacing an existing name-owner.
+ * or replacing an existing name-owner. This makes a synchronous call to the
+ * bus daemon.
  *
- * For internal use by TpBaseConnection, TpBaseConnectionManager.
+ * Returns: %TRUE if @well_known_name was claimed, or %FALSE and sets @error if
+ *          an error occurred.
+ *
+ * Since: 0.7.30
  */
 gboolean
-_tp_dbus_daemon_request_name (TpDBusDaemon *self,
-                              const gchar *well_known_name,
-                              gboolean idempotent,
-                              GError **error)
+tp_dbus_daemon_request_name (TpDBusDaemon *self,
+                             const gchar *well_known_name,
+                             gboolean idempotent,
+                             GError **error)
 {
   TpProxy *as_proxy = (TpProxy *) self;
-  DBusGConnection *gconn = as_proxy->dbus_connection;
-  DBusConnection *dbc = dbus_g_connection_get_connection (gconn);
+  DBusGConnection *gconn;
+  DBusConnection *dbc;
   DBusError dbus_error;
   int result;
+  const GError *invalidated;
 
   g_return_val_if_fail (TP_IS_DBUS_DAEMON (self), FALSE);
   g_return_val_if_fail (tp_dbus_check_valid_bus_name (well_known_name,
         TP_DBUS_NAME_TYPE_WELL_KNOWN, error), FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+  invalidated = tp_proxy_get_invalidated (self);
+
+  if (invalidated != NULL)
+    {
+      if (error != NULL)
+        *error = g_error_copy (invalidated);
+
+      return FALSE;
+    }
+
+  gconn = as_proxy->dbus_connection;
+  dbc = dbus_g_connection_get_connection (gconn);
 
   dbus_error_init (&dbus_error);
   result = dbus_bus_request_name (dbc, well_known_name,
@@ -1105,30 +1141,48 @@ _tp_dbus_daemon_request_name (TpDBusDaemon *self,
 }
 
 /**
- * _tp_dbus_daemon_release_name:
+ * tp_dbus_daemon_release_name:
  * @self: a TpDBusDaemon
- * @well_known_name: a well-known name to acquire
+ * @well_known_name: a well-known name owned by this process to release
  * @error: used to raise an error if %FALSE is returned
  *
- * Release the given well-known name.
+ * Release the given well-known name. This makes a synchronous call to the bus
+ * daemon.
  *
- * For internal use by TpBaseConnection, TpBaseConnectionManager.
+ * Returns: %TRUE if @well_known_name was released, or %FALSE and sets @error
+ *          if an error occurred.
+ *
+ * Since: 0.7.30
  */
 gboolean
-_tp_dbus_daemon_release_name (TpDBusDaemon *self,
-                              const gchar *well_known_name,
-                              GError **error)
+tp_dbus_daemon_release_name (TpDBusDaemon *self,
+                             const gchar *well_known_name,
+                             GError **error)
 {
   TpProxy *as_proxy = (TpProxy *) self;
-  DBusGConnection *gconn = as_proxy->dbus_connection;
-  DBusConnection *dbc = dbus_g_connection_get_connection (gconn);
+  DBusGConnection *gconn;
+  DBusConnection *dbc;
   DBusError dbus_error;
   int result;
+  const GError *invalidated;
 
   g_return_val_if_fail (TP_IS_DBUS_DAEMON (self), FALSE);
   g_return_val_if_fail (tp_dbus_check_valid_bus_name (well_known_name,
         TP_DBUS_NAME_TYPE_WELL_KNOWN, error), FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
+  invalidated = tp_proxy_get_invalidated (self);
+
+  if (invalidated != NULL)
+    {
+      if (error != NULL)
+        *error = g_error_copy (invalidated);
+
+      return FALSE;
+    }
+
+  gconn = as_proxy->dbus_connection;
+  dbc = dbus_g_connection_get_connection (gconn);
   dbus_error_init (&dbus_error);
   result = dbus_bus_release_name (dbc, well_known_name, &dbus_error);
 
