@@ -19,14 +19,6 @@
 #include "tests/lib/myassert.h"
 #include "tests/lib/util.h"
 
-static int fail = 0;
-
-static void
-myassert_failed (void)
-{
-  fail = 1;
-}
-
 static void
 test_simple_presence (ContactsConnection *service_conn,
                       TpConnection *client_conn)
@@ -39,7 +31,7 @@ test_simple_presence (ContactsConnection *service_conn,
   MYASSERT (tp_cli_dbus_properties_run_get (client_conn, -1,
         TP_IFACE_CONNECTION_INTERFACE_SIMPLE_PRESENCE, "Statuses",
         &value, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (G_VALUE_TYPE (value) == TP_HASH_TYPE_SIMPLE_STATUS_SPEC_MAP,
       ": %s != %s", G_VALUE_TYPE_NAME (value),
@@ -98,7 +90,7 @@ test_simple_presence (ContactsConnection *service_conn,
 
   MYASSERT (tp_cli_connection_interface_simple_presence_run_set_presence (
         client_conn, -1, "available", "Here I am", &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 }
 
 static void
@@ -113,7 +105,7 @@ test_complex_presence (ContactsConnection *service_conn,
 
   MYASSERT (tp_cli_connection_interface_presence_run_get_statuses (
         client_conn, -1, &statuses, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   spec = g_hash_table_lookup (statuses, "available");
   MYASSERT (spec != NULL, "");
@@ -198,12 +190,14 @@ test_complex_presence (ContactsConnection *service_conn,
 
   MYASSERT (tp_cli_connection_interface_presence_run_set_status (
         client_conn, -1, monster, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   g_hash_table_destroy (params);
   params = NULL;
   g_hash_table_destroy (monster);
   monster = NULL;
+  g_hash_table_destroy (statuses);
+  statuses = NULL;
 }
 
 int
@@ -235,14 +229,14 @@ main (int argc,
 
   MYASSERT (tp_base_connection_register (service_conn_as_base, "simple",
         &name, &conn_path, &error), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   client_conn = tp_connection_new (dbus, name, conn_path, &error);
   MYASSERT (client_conn != NULL, "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
   MYASSERT (tp_connection_run_until_ready (client_conn, TRUE, &error, NULL),
       "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   /* Tests */
 
@@ -253,7 +247,7 @@ main (int argc,
 
   MYASSERT (tp_cli_connection_run_disconnect (client_conn, -1, &error, NULL),
       "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
   g_object_unref (client_conn);
 
   service_conn_as_base = NULL;
@@ -263,5 +257,5 @@ main (int argc,
 
   g_object_unref (dbus);
 
-  return fail;
+  return 0;
 }
